summaryrefslogtreecommitdiffstats
path: root/src/groupdef.h
diff options
context:
space:
mode:
authordimitri <dimitri@afe2bf4a-e733-0410-8a33-86f594647bc7>2000-05-08 20:42:05 (GMT)
committerdimitri <dimitri@afe2bf4a-e733-0410-8a33-86f594647bc7>2000-05-08 20:42:05 (GMT)
commit6c268019f8ce8b58058e7f7f8204c82b8d0ac190 (patch)
tree28a24e8c88d32a50bc5bef6d49306553267dc5ab /src/groupdef.h
parentb5fb0aa0f1c2a5373ed97b127e2daeeb81ab38f2 (diff)
downloadDoxygen-6c268019f8ce8b58058e7f7f8204c82b8d0ac190.zip
Doxygen-6c268019f8ce8b58058e7f7f8204c82b8d0ac190.tar.gz
Doxygen-6c268019f8ce8b58058e7f7f8204c82b8d0ac190.tar.bz2
Release-1.1.3
Diffstat (limited to 'src/groupdef.h')
-rw-r--r--src/groupdef.h19
1 files changed, 13 insertions, 6 deletions
diff --git a/src/groupdef.h b/src/groupdef.h
index f35536a..03adc17 100644
--- a/src/groupdef.h
+++ b/src/groupdef.h
@@ -41,12 +41,12 @@ class GroupDef : public Definition
public:
GroupDef(const char *name,const char *title);
~GroupDef();
- //const char *groupFile() const { return fileName; }
QCString getOutputFileBase() const { return fileName; }
const char *groupTitle() const { return title; }
void addFile(const FileDef *def);
void addClass(const ClassDef *def);
void addNamespace(const NamespaceDef *def);
+ void addGroup(const GroupDef *def);
void insertMember(MemberDef *def,int groupId);
void addMemberToGroup(MemberDef *def,int groupId);
void writeDocumentation(OutputList &ol);
@@ -64,13 +64,15 @@ class GroupDef : public Definition
private:
QCString title; // title of the group
QCString fileName; // base name of the generated file
- FileList *fileList; // list of all files in the group
- ClassList *classList; // list of all classes in the group
- NamespaceList *namespaceList; // list of all namespace in the group
+ FileList *fileList; // list of files in the group
+ ClassList *classList; // list of classes in the group
+ NamespaceList *namespaceList; // list of namespaces in the group
+ GroupList *groupList; // list of sub groups.
MemberList *allMemberList; // list of all members in the group
QDict<MemberDef> *allMemberDict;
- // members sorted to type
+
+ // members sorted by type
MemberList defineMembers;
MemberList protoMembers;
MemberList typedefMembers;
@@ -80,7 +82,7 @@ class GroupDef : public Definition
MemberList varMembers;
/* user defined member groups */
- MemberGroupList *memberGroupList;
+ MemberGroupList *memberGroupList; // list of member groups in this group
MemberGroupDict *memberGroupDict;
};
@@ -95,4 +97,9 @@ class GroupListIterator : public QListIterator<GroupDef>
GroupListIterator(const GroupList &l) : QListIterator<GroupDef>(l) {}
};
+void addClassToGroups(Entry *root,ClassDef *cd);
+void addNamespaceToGroups(Entry *root,NamespaceDef *nd);
+void addGroupToGroups(Entry *root,GroupDef *subGroup);
+void addMemberToGroups(Entry *root,MemberDef *md);
+
#endif